@@ -49,6 +49,7 @@
 #include "nautilus-application.h"
 #include "nautilus-bookmark-list.h"
 #include "nautilus-places-sidebar.h"
+#include "nautilus-properties-window.h"
 #include "nautilus-window.h"
 #include "nautilus-window-slot.h"
 
@@ -91,6 +92,8 @@ typedef struct {
 	GtkWidget *popup_menu_empty_trash_item;
 	GtkWidget *popup_menu_start_item;
 	GtkWidget *popup_menu_stop_item;
+	GtkWidget *popup_menu_properties_separator_item;
+	GtkWidget *popup_menu_properties_item;
 
 	/* volume mounting - delayed open process */
 	gboolean mounting;
@@ -1069,10 +1072,8 @@ compute_drop_position (GtkTreeView *tree_view,
 	SectionType section_type;
 
 	if (!gtk_tree_view_get_dest_row_at_pos (tree_view,
-					   x,
-					   y,
-					   path,
-					   pos)) {
+						x, y,
+						path, pos)) {
 		return FALSE;
 	}
 
@@ -1377,9 +1378,9 @@ reorder_bookmarks (NautilusPlacesSidebar *sidebar,
 	int old_position;
 
 	/* Get the selected path */
-
-	if (!get_selected_iter (sidebar, &iter))
-		g_assert_not_reached ();
+	if (!get_selected_iter (sidebar, &iter)) {
+		return;
+	}
 
 	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->filter_model), &iter,
 			    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
@@ -1438,7 +1439,10 @@ drag_data_received_callback (GtkWidget *widget,
 	}
 
 	/* Compute position */
-	compute_drop_position (tree_view, x, y, &tree_path, &tree_pos, sidebar);
+	success = compute_drop_position (tree_view, x, y, &tree_path, &tree_pos, sidebar);
+	if (!success) {
+		goto out;
+	}
 
 	success = FALSE;
 
@@ -1566,6 +1570,8 @@ bookmarks_popup_menu_detach_cb (GtkWidget *attach_widget,
 	sidebar->popup_menu_start_item = NULL;
 	sidebar->popup_menu_stop_item = NULL;
 	sidebar->popup_menu_empty_trash_item = NULL;
+	sidebar->popup_menu_properties_separator_item = NULL;
+	sidebar->popup_menu_properties_item = NULL;
 }
 
 static void
@@ -1636,6 +1642,8 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	GDrive *drive = NULL;
 	GVolume *volume = NULL;
 	GMount *mount = NULL;
+	GFile *location;
+	NautilusDirectory *directory;
 	gboolean show_mount;
 	gboolean show_unmount;
 	gboolean show_eject;
@@ -1643,6 +1651,7 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	gboolean show_start;
 	gboolean show_stop;
 	gboolean show_empty_trash;
+	gboolean show_properties;
 	char *uri = NULL;
 	
 	type = PLACES_BUILT_IN;
@@ -1677,6 +1686,18 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	show_empty_trash = (uri != NULL) &&
 			   (!strcmp (uri, "trash:///"));
 
+	/* Only show properties for local mounts */
+	show_properties = (mount != NULL);
+	if (mount != NULL) {
+		location = g_mount_get_default_location (mount);
+		directory = nautilus_directory_get (location);
+
+		show_properties = nautilus_directory_is_local (directory);
+
+		nautilus_directory_unref (directory);
+		g_object_unref (location);
+	}
+
 	gtk_widget_set_visible (sidebar->popup_menu_separator_item,
 		      show_mount || show_unmount || show_eject || show_empty_trash);
 	gtk_widget_set_visible (sidebar->popup_menu_mount_item, show_mount);
@@ -1686,6 +1707,8 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	gtk_widget_set_visible (sidebar->popup_menu_start_item, show_start);
 	gtk_widget_set_visible (sidebar->popup_menu_stop_item, show_stop);
 	gtk_widget_set_visible (sidebar->popup_menu_empty_trash_item, show_empty_trash);
+	gtk_widget_set_visible (sidebar->popup_menu_properties_separator_item, show_properties);
+	gtk_widget_set_visible (sidebar->popup_menu_properties_item, show_properties);
 
 	/* Adjust start/stop items to reflect the type of the drive */
 	gtk_menu_item_set_label (GTK_MENU_ITEM (sidebar->popup_menu_start_item), _("_Start"));
@@ -1873,15 +1896,15 @@ open_shortcut_from_menu (NautilusPlacesSidebar *sidebar,
 			 NautilusWindowOpenFlags	       flags)
 {
 	GtkTreeModel *model;
-	GtkTreePath *path;
 	GtkTreeIter iter;
+	GtkTreePath *path = NULL;
 
 	model = gtk_tree_view_get_model (sidebar->tree_view);
 	gtk_tree_view_get_cursor (sidebar->tree_view, &path, NULL);
 
-	gtk_tree_model_get_iter (model, &iter, path);
-
-	open_selected_bookmark (sidebar, model, &iter, flags);
+	if (path != NULL && gtk_tree_model_get_iter (model, &iter, path)) {
+		open_selected_bookmark (sidebar, model, &iter, flags);
+	}
 
 	gtk_tree_path_free (path);
 }
@@ -2496,6 +2519,41 @@ find_next_row (NautilusPlacesSidebar *sidebar, GtkTreeIter *iter)
 	return find_prev_or_next_row (sidebar, iter, FALSE);
 }
 
+static void
+properties_cb (GtkMenuItem           *item,
+	       NautilusPlacesSidebar *sidebar)
+{
+	GtkTreeModel *model;
+	GtkTreePath *path = NULL;
+	GtkTreeIter iter;
+	GList *list;
+	NautilusFile *file;
+	char *uri;
+
+	model = gtk_tree_view_get_model (sidebar->tree_view);
+	gtk_tree_view_get_cursor (sidebar->tree_view, &path, NULL);
+
+	if (path == NULL || !gtk_tree_model_get_iter (model, &iter, path)) {
+		gtk_tree_path_free (path);
+		return;
+	}
+
+	gtk_tree_model_get (model, &iter, PLACES_SIDEBAR_COLUMN_URI, &uri, -1);
+
+	if (uri != NULL) {
+
+		file = nautilus_file_get_by_uri (uri);
+		list = g_list_prepend (NULL, nautilus_file_ref (file));
+
+		nautilus_properties_window_present (list, GTK_WIDGET (sidebar));
+
+		nautilus_file_list_free (list);
+		g_free (uri);
+	}
+
+	gtk_tree_path_free (path);
+}
+
 /* Handler for GtkWidget::key-press-event on the shortcuts list */
 static gboolean
 bookmarks_key_press_event_cb (GtkWidget             *widget,
@@ -2695,6 +2753,18 @@ bookmarks_build_popup_menu (NautilusPlacesSidebar *sidebar)
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (sidebar->popup_menu), item);
 
+	/* Properties menu item */
+
+	sidebar->popup_menu_properties_separator_item =
+		GTK_WIDGET (eel_gtk_menu_append_separator (GTK_MENU (sidebar->popup_menu)));
+
+	item = gtk_menu_item_new_with_mnemonic (_("_Properties"));
+	sidebar->popup_menu_properties_item = item;
+	g_signal_connect (item, "activate",
+			  G_CALLBACK (properties_cb), sidebar);
+	gtk_widget_show (item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (sidebar->popup_menu), item);
+
 	bookmarks_check_popup_sensitivity (sidebar);
 }
 
@@ -2710,9 +2780,7 @@ bookmarks_popup_menu (NautilusPlacesSidebar *sidebar,
 {
 	bookmarks_update_popup_menu (sidebar);
 	eel_pop_up_context_menu (GTK_MENU(sidebar->popup_menu),
-			      EEL_DEFAULT_POPUP_MENU_DISPLACEMENT,
-			      EEL_DEFAULT_POPUP_MENU_DISPLACEMENT,
-			      event);
+				 event);
 }
 
 /* Callback used for the GtkWidget::popup-menu signal of the shortcuts list */
@@ -2878,35 +2946,32 @@ static gboolean
 bookmarks_button_press_event_cb (GtkWidget             *widget,
 				 GdkEventButton        *event,
 				 NautilusPlacesSidebar *sidebar)
+
 {
+	GtkTreeModel *model;
+	GtkTreeView *tree_view;
+	GtkTreeIter iter;
+	GtkTreePath *path = NULL;
+	gboolean retval = FALSE;
+
 	if (event->type != GDK_BUTTON_PRESS) {
 		/* ignore multiple clicks */
 		return TRUE;
 	}
 
+	tree_view = GTK_TREE_VIEW (widget);
+	model = gtk_tree_view_get_model (tree_view);
+	gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y, 
+				       &path, NULL, NULL, NULL);
+
+	if (path == NULL || !gtk_tree_model_get_iter (model, &iter, path)) {
+		return FALSE;
+	}
+
 	if (event->button == 3) {
 		bookmarks_popup_menu (sidebar, event);
 	} else if (event->button == 2) {
-		GtkTreeModel *model;
-		GtkTreePath *path;
-		GtkTreeIter iter;
-		GtkTreeView *tree_view;
 		NautilusWindowOpenFlags flags = 0;
-		gboolean res;
-
-		tree_view = GTK_TREE_VIEW (widget);
-		g_assert (tree_view == sidebar->tree_view);
-
-		model = gtk_tree_view_get_model (tree_view);
-
-		res = gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y, 
-						     &path, NULL, NULL, NULL);
-
-		if (!res) {
-			return FALSE;
-		}
-
-		gtk_tree_model_get_iter (model, &iter, path);
 
 		if (g_settings_get_boolean (nautilus_preferences,
 					    NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
@@ -2918,14 +2983,12 @@ bookmarks_button_press_event_cb (GtkWidget             *widget,
 		}
 
 		open_selected_bookmark (sidebar, model, &iter, flags);
-
-		if (path != NULL) {
-			gtk_tree_path_free (path);
-			return TRUE;
-		}
+		retval = TRUE;
 	}
 
-	return FALSE;
+	gtk_tree_path_free (path);
+
+	return retval;
 }
 
 
